blockSelectionMargin abstract method
Margin to apply around block selection highlights, resolved from the block component builder configuration.
Implementation
EdgeInsets? blockSelectionMargin(Node node);
Margin to apply around block selection highlights, resolved from the block component builder configuration.
EdgeInsets? blockSelectionMargin(Node node);