MoveDirection enum

Direction of a cursor or selection movement, triggered by user input (arrows, Home/End, PgUp/PgDn, Ctrl+arrows for word navigation).

Inheritance
Available extensions

Values

up → const MoveDirection

Arrow up.

down → const MoveDirection

Arrow down.

left → const MoveDirection

Arrow left.

Arrow right.

lineStart → const MoveDirection

Home key — start of visual line.

lineEnd → const MoveDirection

End key — end of visual line.

pageUp → const MoveDirection

Page up.

pageDown → const MoveDirection

Page down.

wordLeft → const MoveDirection

Ctrl+Arrow left — previous word boundary.

wordRight → const MoveDirection

Ctrl+Arrow right — next word boundary.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MoveDirection>
A constant List of the values in this enum, in order of their declaration.