SelectionLifecycleContext class

Context passed to SelectionRenderer.onSelectionStarted and SelectionRenderer.onSelectionEnded when the user starts or finishes a selection drag.

Constructors

SelectionLifecycleContext({required Selection selection, Node? startNode, Node? endNode, required bool isCollapsed})
const

Properties

endNode → Node?
The node at the end of the selection.
final
hashCode int
The hash code for this object.
no setterinherited
isCollapsed bool
Whether the selection is collapsed (caret) or expanded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection → Selection
The current selection state.
final
startNode → Node?
The node at the start of the selection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited