AnimatedSelectionAreaPaint class
A selection highlight widget that paints rectangles with an animated gradient. The gradient rotates continuously when withAnimation is true.
All animation parameters are customizable:
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedSelectionAreaPaint
Constructors
-
AnimatedSelectionAreaPaint({Key? key, required List<
Rect> rects, bool withAnimation = false, List<Color> colors = const [Color.fromARGB(255, 65, 88, 208), Color.fromARGB(255, 200, 80, 192), Color.fromARGB(255, 255, 204, 112)], Duration duration = const Duration(seconds: 4), Curve curve = Curves.bounceInOut}) -
const
Properties
-
colors
→ List<
Color> -
The gradient colors. Must have at least 2 colors.
final
- curve → Curve
-
Easing curve applied to the rotation tween.
final
- duration → Duration
-
Duration of one full gradient rotation cycle.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
rects
→ List<
Rect> -
The rectangles to fill with the gradient.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- withAnimation → bool
-
Whether the gradient rotates over time.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AnimatedSelectionAreaPaint> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited