minRectWidth property
Width used for zero-width rects so the selection is still visible (e.g. at the end of a line with no content). Defaults to 8.0.
Implementation
final double minRectWidth;
Width used for zero-width rects so the selection is still visible (e.g. at the end of a line with no content). Defaults to 8.0.
final double minRectWidth;